==> aws-sdk-2.212.1.jar: META-INF/resources/webjars/aws-sdk/2.212.1/clients/all.d.ts <==
export import ACM = require('./acm');
export import APIGateway = require('./apigateway');
export import ApplicationAutoScaling = require('./applicationautoscaling');
export import AppStream = require('./appstream');
export import AutoScaling = require('./autoscaling');
export import Batch = require('./batch');
export import Budgets = require('./budgets');
export import CloudDirectory = require('./clouddirectory');
export import CloudFormation = require('./cloudformation');
export import CloudFront = require('./cloudfront');
export import CloudHSM = require('./cloudhsm');
export import CloudSearch = require('./cloudsearch');
export import CloudSearchDomain = require('./cloudsearchdomain');
export import CloudTrail = require('./cloudtrail');
export import CloudWatch = require('./cloudwatch');
export import CloudWatchEvents = require('./cloudwatchevents');
export import CloudWatchLogs = require('./cloudwatchlogs');
export import CodeBuild = require('./codebuild');
export import CodeCommit = require('./codecommit');
export import CodeDeploy = require('./codedeploy');
export import CodePipeline = require('./codepipeline');
export import CognitoIdentity = require('./cognitoidentity');
export import CognitoIdentityServiceProvider = require('./cognitoidentityserviceprovider');
export import CognitoSync = require('./cognitosync');
export import ConfigService = require('./configservice');
export import CUR = require('./cur');
export import DataPipeline = require('./datapipeline');
export import DeviceFarm = require('./devicefarm');
export import DirectConnect = require('./directconnect');
export import DirectoryService = require('./directoryservice');
export import Discovery = require('./discovery');
export import DMS = require('./dms');
export import DynamoDB = require('./dynamodb');
export import DynamoDBStreams = require('./dynamodbstreams');
export import EC2 = require('./ec2');
export import ECR = require('./ecr');
export import ECS = require('./ecs');
export import EFS = require('./efs');
export import ElastiCache = require('./elasticache');
export import ElasticBeanstalk = require('./elasticbeanstalk');
export import ELB = require('./elb');
export import ELBv2 = require('./elbv2');
export import EMR = require('./emr');
export import ES = require('./es');
export import ElasticTranscoder = require('./elastictranscoder');
export import Firehose = require('./firehose');
export import GameLift = require('./gamelift');
export import Glacier = require('./glacier');
export import Health = require('./health');
export import IAM = require('./iam');
export import ImportExport = require('./importexport');
export import Inspector = require('./inspector');
export import Iot = require('./iot');
export import IotData = require('./iotdata');
export import Kinesis = require('./kinesis');
export import KinesisAnalytics = require('./kinesisanalytics');
export import KMS = require('./kms');
export import Lambda = require('./lambda');
export import LexRuntime = require('./lexruntime');
export import Lightsail = require('./lightsail');
export import MachineLearning = require('./machinelearning');
export import MarketplaceCommerceAnalytics = require('./marketplacecommerceanalytics');
export import MarketplaceMetering = require('./marketplacemetering');
export import MTurk = require('./mturk');
export import MobileAnalytics = require('./mobileanalytics');
export import OpsWorks = require('./opsworks');
export import OpsWorksCM = require('./opsworkscm');
export import Organizations = require('./organizations');
export import Pinpoint = require('./pinpoint');
export import Polly = require('./polly');
export import RDS = require('./rds');
export import Redshift = require('./redshift');
export import Rekognition = require('./rekognition');
export import ResourceGroupsTaggingAPI = require('./resourcegroupstaggingapi');
export import Route53 = require('./route53');
export import Route53Domains = require('./route53domains');
export import S3 = require('./s3');
export import ServiceCatalog = require('./servicecatalog');
export import SES = require('./ses');
export import Shield = require('./shield');
export import SimpleDB = require('./simpledb');
export import SMS = require('./sms');
export import Snowball = require('./snowball');
export import SNS = require('./sns');
export import SQS = require('./sqs');
export import SSM = require('./ssm');
export import StorageGateway = require('./storagegateway');
export import StepFunctions = require('./stepfunctions');
export import STS = require('./sts');
export import Support = require('./support');
export import SWF = require('./swf');
export import XRay = require('./xray');
export import WAF = require('./waf');
export import WAFRegional = require('./wafregional');
export import WorkDocs = require('./workdocs');
export import WorkSpaces = require('./workspaces');
export import CodeStar = require('./codestar');
export import LexModelBuildingService = require('./lexmodelbuildingservice');
export import MarketplaceEntitlementService = require('./marketplaceentitlementservice');
export import Athena = require('./athena');
export import Greengrass = require('./greengrass');
export import DAX = require('./dax');
export import MigrationHub = require('./migrationhub');
export import CloudHSMV2 = require('./cloudhsmv2');
export import Glue = require('./glue');
export import Mobile = require('./mobile');
export import Pricing = require('./pricing');
export import CostExplorer = require('./costexplorer');
export import MediaConvert = require('./mediaconvert');
export import MediaLive = require('./medialive');
export import MediaPackage = require('./mediapackage');
export import MediaStore = require('./mediastore');
export import MediaStoreData = require('./mediastoredata');
export import AppSync = require('./appsync');
export import GuardDuty = require('./guardduty');
export import MQ = require('./mq');
export import Comprehend = require('./comprehend');
export import IoTJobsDataPlane = require('./iotjobsdataplane');
export import KinesisVideoArchivedMedia = require('./kinesisvideoarchivedmedia');
export import KinesisVideoMedia = require('./kinesisvideomedia');
export import KinesisVideo = require('./kinesisvideo');
export import SageMakerRuntime = require('./sagemakerruntime');
export import SageMaker = require('./sagemaker');
export import Translate = require('./translate');
export import ResourceGroups = require('./resourcegroups');
export import AlexaForBusiness = require('./alexaforbusiness');
export import Cloud9 = require('./cloud9');
export import ServerlessApplicationRepository = require('./serverlessapplicationrepository');
export import ServiceDiscovery = require('./servicediscovery');
export import WorkMail = require('./workmail');
export import AutoScalingPlans = require('./autoscalingplans');
export import TranscribeService = require('./transcribeservice');

==> aws-sdk-2.366.0.jar: META-INF/resources/webjars/aws-sdk/2.366.0/clients/all.d.ts <==
export import ACM = require('./acm');
export import APIGateway = require('./apigateway');
export import ApplicationAutoScaling = require('./applicationautoscaling');
export import AppStream = require('./appstream');
export import AutoScaling = require('./autoscaling');
export import Batch = require('./batch');
export import Budgets = require('./budgets');
export import CloudDirectory = require('./clouddirectory');
export import CloudFormation = require('./cloudformation');
export import CloudFront = require('./cloudfront');
export import CloudHSM = require('./cloudhsm');
export import CloudSearch = require('./cloudsearch');
export import CloudSearchDomain = require('./cloudsearchdomain');
export import CloudTrail = require('./cloudtrail');
export import CloudWatch = require('./cloudwatch');
export import CloudWatchEvents = require('./cloudwatchevents');
export import CloudWatchLogs = require('./cloudwatchlogs');
export import CodeBuild = require('./codebuild');
export import CodeCommit = require('./codecommit');
export import CodeDeploy = require('./codedeploy');
export import CodePipeline = require('./codepipeline');
export import CognitoIdentity = require('./cognitoidentity');
export import CognitoIdentityServiceProvider = require('./cognitoidentityserviceprovider');
export import CognitoSync = require('./cognitosync');
export import ConfigService = require('./configservice');
export import CUR = require('./cur');
export import DataPipeline = require('./datapipeline');
export import DeviceFarm = require('./devicefarm');
export import DirectConnect = require('./directconnect');
export import DirectoryService = require('./directoryservice');
export import Discovery = require('./discovery');
export import DMS = require('./dms');
export import DynamoDB = require('./dynamodb');
export import DynamoDBStreams = require('./dynamodbstreams');
export import EC2 = require('./ec2');
export import ECR = require('./ecr');
export import ECS = require('./ecs');
export import EFS = require('./efs');
export import ElastiCache = require('./elasticache');
export import ElasticBeanstalk = require('./elasticbeanstalk');
export import ELB = require('./elb');
export import ELBv2 = require('./elbv2');
export import EMR = require('./emr');
export import ES = require('./es');
export import ElasticTranscoder = require('./elastictranscoder');
export import Firehose = require('./firehose');
export import GameLift = require('./gamelift');
export import Glacier = require('./glacier');
export import Health = require('./health');
export import IAM = require('./iam');
export import ImportExport = require('./importexport');
export import Inspector = require('./inspector');
export import Iot = require('./iot');
export import IotData = require('./iotdata');
export import Kinesis = require('./kinesis');
export import KinesisAnalytics = require('./kinesisanalytics');
export import KMS = require('./kms');
export import Lambda = require('./lambda');
export import LexRuntime = require('./lexruntime');
export import Lightsail = require('./lightsail');
export import MachineLearning = require('./machinelearning');
export import MarketplaceCommerceAnalytics = require('./marketplacecommerceanalytics');
export import MarketplaceMetering = require('./marketplacemetering');
export import MTurk = require('./mturk');
export import MobileAnalytics = require('./mobileanalytics');
export import OpsWorks = require('./opsworks');
export import OpsWorksCM = require('./opsworkscm');
export import Organizations = require('./organizations');
export import Pinpoint = require('./pinpoint');
export import Polly = require('./polly');
export import RDS = require('./rds');
export import Redshift = require('./redshift');
export import Rekognition = require('./rekognition');
export import ResourceGroupsTaggingAPI = require('./resourcegroupstaggingapi');
export import Route53 = require('./route53');
export import Route53Domains = require('./route53domains');
export import S3 = require('./s3');
export import S3Control = require('./s3control');
export import ServiceCatalog = require('./servicecatalog');
export import SES = require('./ses');
export import Shield = require('./shield');
export import SimpleDB = require('./simpledb');
export import SMS = require('./sms');
export import Snowball = require('./snowball');
export import SNS = require('./sns');
export import SQS = require('./sqs');
export import SSM = require('./ssm');
export import StorageGateway = require('./storagegateway');
export import StepFunctions = require('./stepfunctions');
export import STS = require('./sts');
export import Support = require('./support');
export import SWF = require('./swf');
export import XRay = require('./xray');
export import WAF = require('./waf');
export import WAFRegional = require('./wafregional');
export import WorkDocs = require('./workdocs');
export import WorkSpaces = require('./workspaces');
export import CodeStar = require('./codestar');
export import LexModelBuildingService = require('./lexmodelbuildingservice');
export import MarketplaceEntitlementService = require('./marketplaceentitlementservice');
export import Athena = require('./athena');
export import Greengrass = require('./greengrass');
export import DAX = require('./dax');
export import MigrationHub = require('./migrationhub');
export import CloudHSMV2 = require('./cloudhsmv2');
export import Glue = require('./glue');
export import Mobile = require('./mobile');
export import Pricing = require('./pricing');
export import CostExplorer = require('./costexplorer');
export import MediaConvert = require('./mediaconvert');
export import MediaLive = require('./medialive');
export import MediaPackage = require('./mediapackage');
export import MediaStore = require('./mediastore');
export import MediaStoreData = require('./mediastoredata');
export import AppSync = require('./appsync');
export import GuardDuty = require('./guardduty');
export import MQ = require('./mq');
export import Comprehend = require('./comprehend');
export import IoTJobsDataPlane = require('./iotjobsdataplane');
export import KinesisVideoArchivedMedia = require('./kinesisvideoarchivedmedia');
export import KinesisVideoMedia = require('./kinesisvideomedia');
export import KinesisVideo = require('./kinesisvideo');
export import SageMakerRuntime = require('./sagemakerruntime');
export import SageMaker = require('./sagemaker');
export import Translate = require('./translate');
export import ResourceGroups = require('./resourcegroups');
export import AlexaForBusiness = require('./alexaforbusiness');
export import Cloud9 = require('./cloud9');
export import ServerlessApplicationRepository = require('./serverlessapplicationrepository');
export import ServiceDiscovery = require('./servicediscovery');
export import WorkMail = require('./workmail');
export import AutoScalingPlans = require('./autoscalingplans');
export import TranscribeService = require('./transcribeservice');
export import Connect = require('./connect');
export import ACMPCA = require('./acmpca');
export import FMS = require('./fms');
export import SecretsManager = require('./secretsmanager');
export import IoTAnalytics = require('./iotanalytics');
export import IoT1ClickDevicesService = require('./iot1clickdevicesservice');
export import IoT1ClickProjects = require('./iot1clickprojects');
export import PI = require('./pi');
export import Neptune = require('./neptune');
export import MediaTailor = require('./mediatailor');
export import EKS = require('./eks');
export import Macie = require('./macie');
export import DLM = require('./dlm');
export import Signer = require('./signer');
export import Chime = require('./chime');
export import PinpointEmail = require('./pinpointemail');
export import RAM = require('./ram');
export import Route53Resolver = require('./route53resolver');
export import PinpointSMSVoice = require('./pinpointsmsvoice');
export import QuickSight = require('./quicksight');
export import RDSDataService = require('./rdsdataservice');
export import Amplify = require('./amplify');
export import DataSync = require('./datasync');
export import RoboMaker = require('./robomaker');
export import Transfer = require('./transfer');
export import GlobalAccelerator = require('./globalaccelerator');
export import ComprehendMedical = require('./comprehendmedical');
export import KinesisAnalyticsV2 = require('./kinesisanalyticsv2');
export import MediaConnect = require('./mediaconnect');
export import FSx = require('./fsx');
export import SecurityHub = require('./securityhub');
export import AppMesh = require('./appmesh');
export import LicenseManager = require('./licensemanager');
